@@ -184,7 +184,7 @@ static void 	BreakArgs (char *Input, char **Sender, const char **OutPut)
 		{
 			/* Squash the : so if PasteArgs() is called it doesn't reappear */
 			ov_strcpy(Input, Input + 1);
-			OutPut[ArgCount++] = ++Input;
+			OutPut[ArgCount++] = Input;
 			break;
 		}
 
@@ -435,10 +435,9 @@ static void	p_privmsg (const char *from, const char *comm, const char **ArgList)
 		{
 		    if (away)
 		    {
-			time_t blah = time(NULL);
 			put_it("%s*%s*%s %s <%.16s>", 
 				high, from, high, message, 
-				ctime(&blah));
+				my_ctime(time(NULL)));
 		    }
 		    else
 			put_it("%s*%s*%s %s", high, from, high,message);
