@@ -1941,7 +1941,12 @@ void	register_server (int refnum, const char *nick)
 #endif
 	}
 	if (s->password)
-		send_to_aserver(refnum, "PASS %s", s->password);
+	{
+		char *dequoted = NULL;
+		malloc_strcat_ues(&dequoted, s->password, "\\:");
+		send_to_aserver(refnum, "PASS %s", dequoted);
+		new_free(&dequoted);
+	}
 
 	send_to_aserver(refnum, "USER %s %s %s :%s", username, 
 			(send_umode && *send_umode) ? send_umode : 
